==> sdk-4.1.0-sources.jar: com/kontakt/sdk/android/ble/util/DeviceUtils.java <==
package com.kontakt.sdk.android.ble.util;

import com.kontakt.sdk.android.common.model.Device;
import com.kontakt.sdk.android.common.model.FirmwareVersion;
import com.kontakt.sdk.android.common.model.Model;
import com.kontakt.sdk.android.common.profile.RemoteBluetoothDevice;

import java.util.EnumSet;

import static com.kontakt.sdk.android.common.model.Model.*;
import static com.kontakt.sdk.android.common.util.SDKPreconditions.checkNotNull;

public final class DeviceUtils {

    private static final EnumSet<Model> SECURE_PROFILES = EnumSet.of(
            GATEWAY,
            BEACON_PRO,
            PROBE,
            TAG_BEACON,
            SMART_BEACON_3,
            SMART_BEACON_3H,
            HEAVY_DUTY_BEACON,
            CARD_BEACON_2,
            TOUGH_BEACON_2,
            BRACELET_TAG,
            UNIVERSAL_TAG,
            BRACELET_TAG_2
    );

    private DeviceUtils() {
        // prevent from creation
    }

    // Secure check methods

    public static boolean isSecure(final Device device) {
        checkNotNull(device, "Device cannot be null");
        return isSecure(device.getModel(), device.getFirmware());
    }

    public static boolean isSecure(final RemoteBluetoothDevice device) {
        checkNotNull(device, "Device cannot be null");
        return isSecure(device.getModel(), device.getFirmwareVersion());
    }

    public static boolean isSecure(final Model model, final String firmware) {
        checkNotNull(model, "Model cannot be null");
        checkNotNull(firmware, "Firmware version cannot be null");

        if (SECURE_PROFILES.contains(model)) {
            return true;
        }

        final FirmwareVersion minFirmwareVersion = new FirmwareVersion("4.0");
        final FirmwareVersion deviceFirmwareVersion = new FirmwareVersion(firmware);

        return deviceFirmwareVersion.isGreaterOrEqualTo(minFirmwareVersion);
    }

    // RTC & light sensor check methods

    public static boolean hasRtcFeature(final Device device) {
        checkNotNull(device, "Device cannot be null");
        return hasRtcFeature(device.getModel(), device.getFirmware());
    }

    public static boolean hasRtcFeature(final RemoteBluetoothDevice device) {
        checkNotNull(device, "Device cannot be null");
        return hasRtcFeature(device.getModel(), device.getFirmwareVersion());
    }

    public static boolean hasRtcFeature(final Model model, final String firmware) {
        checkNotNull(model, "Model cannot be null");
        checkNotNull(firmware, "Firmware version cannot be null");

        if (EnumSet.of(
                TAG_BEACON,
                SMART_BEACON_3,
                SMART_BEACON_3H,
                HEAVY_DUTY_BEACON,
                CARD_BEACON_2,
                TOUGH_BEACON_2,
                BRACELET_TAG,
                UNIVERSAL_TAG,
                BRACELET_TAG_2
        ).contains(model)) {
            return true;
        }

        final FirmwareVersion minFirmwareVersion = new FirmwareVersion("1.7");
        final FirmwareVersion deviceFirmwareVersion = new FirmwareVersion(firmware);

        return model == BEACON_PRO && deviceFirmwareVersion.isGreaterOrEqualTo(minFirmwareVersion);
    }

    public static boolean hasLightSensorFeature(final Device device) {
        checkNotNull(device, "Device cannot be null");
        return hasLightSensorFeature(device.getModel(), device.getFirmware());
    }

    public static boolean hasLightSensorFeature(final RemoteBluetoothDevice device) {
        checkNotNull(device, "Device cannot be null");
        return hasLightSensorFeature(device.getModel(), device.getFirmwareVersion());
    }

    public static boolean hasLightSensorFeature(final Model model, final String firmware) {
        checkNotNull(model, "Model cannot be null");
        checkNotNull(firmware, "Firmware version cannot be null");

        final FirmwareVersion minFirmwareVersion = new FirmwareVersion("1.7");
        final FirmwareVersion deviceFirmwareVersion = new FirmwareVersion(firmware);

        return model == BEACON_PRO && deviceFirmwareVersion.isGreaterOrEqualTo(minFirmwareVersion);
    }

    public static boolean hasRtcAndLightSensorFeatures(final Device device) {
        checkNotNull(device, "Device cannot be null");
        return hasRtcAndLightSensorFeatures(device.getModel(), device.getFirmware());
    }

    public static boolean hasRtcAndLightSensorFeatures(final RemoteBluetoothDevice device) {
        checkNotNull(device, "Device cannot be null");
        return hasRtcAndLightSensorFeatures(device.getModel(), device.getFirmwareVersion());
    }

    public static boolean hasRtcAndLightSensorFeatures(final Model model, final String firmware) {
        checkNotNull(model, "Model cannot be null");
        checkNotNull(firmware, "Firmware version cannot be null");

        return hasRtcFeature(model, firmware) && hasLightSensorFeature(model, firmware);
    }

    // Kontakt Telemetry broadcasting check methods

    public static boolean canTransmitKontaktTelemetry(final Device device) {
        checkNotNull(device, "Device cannot be null");
        return canTransmitKontaktTelemetry(device.getModel(), device.getFirmware());
    }

    public static boolean canTransmitKontaktTelemetry(final Model model, final String firmware) {
        checkNotNull(model, "Model cannot be null");
        checkNotNull(firmware, "Firmware version cannot be null");

        // Check if secure profile and not beacon pro
        if (model != BEACON_PRO && SECURE_PROFILES.contains(model)) {
            return true;
        }

        // If beacon pro then firmware revision must be checked additionally
        final FirmwareVersion minFirmwareVersion = new FirmwareVersion("1.10");
        final FirmwareVersion deviceFirmwareVersion = new FirmwareVersion(firmware);

        return model == BEACON_PRO && deviceFirmwareVersion.isGreaterOrEqualTo(minFirmwareVersion);
    }

    // Interleaving packets check methods

    public static boolean isInterleavingAvailable(final Device device) {
        checkNotNull(device, "Device cannot be null");
        return isInterleavingAvailable(device.getModel(), device.getFirmware());
    }

    public static boolean isInterleavingAvailable(final Model model, final String firmware) {
        checkNotNull(model, "Model cannot be null");
        checkNotNull(firmware, "Firmware version cannot be null");

        if (EnumSet.of(
                BEACON_PRO,
                TAG_BEACON,
                SMART_BEACON_3,
                SMART_BEACON_3H,
                HEAVY_DUTY_BEACON,
                CARD_BEACON_2,
                TOUGH_BEACON_2,
                BRACELET_TAG,
                UNIVERSAL_TAG,
                BRACELET_TAG_2
        ).contains(model)) {
            return true;
        }

        final FirmwareVersion minFirmwareVersion = new FirmwareVersion("4.1");
        final FirmwareVersion deviceFirmwareVersion = new FirmwareVersion(firmware);

        return deviceFirmwareVersion.isGreaterOrEqualTo(minFirmwareVersion);
    }

}

==> sdk-5.0.0-sources.jar: com/kontakt/sdk/android/ble/util/DeviceUtils.java <==
package com.kontakt.sdk.android.ble.util;

import com.kontakt.sdk.android.common.model.Device;
import com.kontakt.sdk.android.common.model.FirmwareVersion;
import com.kontakt.sdk.android.common.model.Model;
import com.kontakt.sdk.android.common.profile.RemoteBluetoothDevice;

import java.util.EnumSet;

import static com.kontakt.sdk.android.common.model.Model.*;
import static com.kontakt.sdk.android.common.util.SDKPreconditions.checkNotNull;

public final class DeviceUtils {

    private static final EnumSet<Model> SECURE_PROFILES = EnumSet.of(
            GATEWAY,
            BEACON_PRO,
            PROBE,
            TAG_BEACON,
            SMART_BEACON_3,
            SMART_BEACON_3H,
            HEAVY_DUTY_BEACON,
            CARD_BEACON_2,
            TOUGH_BEACON_2,
            BRACELET_TAG,
            UNIVERSAL_TAG,
            BRACELET_TAG_2,
            TT_BEACON,
            MINEW_E5,
            MINEW_E7,
            MINEW_E8,
            MINEW_I3,
            MINEW_I7,
            MINEW_S1,
            LANYARD_TAG,
            NANO_TAG,
            PUCK_TAG,
            PORTAL_LIGHT
    );

    private static final EnumSet<Model> GATEWAY_MODELS = EnumSet.of(
      GATEWAY,
      PORTAL_LIGHT
    );

    private DeviceUtils() {
        // prevent from creation
    }

    // Secure check methods

    public static boolean isSecure(Model model){
        return SECURE_PROFILES.contains(model);
    }

    public static boolean isSecure(final Device device) {
        checkNotNull(device, "Device cannot be null");
        return isSecure(device.getModel(), device.getFirmware());
    }

    public static boolean isSecure(final RemoteBluetoothDevice device) {
        checkNotNull(device, "Device cannot be null");
        return isSecure(device.getModel(), device.getFirmwareVersion());
    }

    public static boolean isSecure(final Model model, final String firmware) {
        checkNotNull(model, "Model cannot be null");
        checkNotNull(firmware, "Firmware version cannot be null");

        if (SECURE_PROFILES.contains(model)) {
            return true;
        }

        final FirmwareVersion minFirmwareVersion = new FirmwareVersion("4.0");
        final FirmwareVersion deviceFirmwareVersion = new FirmwareVersion(firmware);

        return deviceFirmwareVersion.isGreaterOrEqualTo(minFirmwareVersion);
    }

    // RTC & light sensor check methods

    public static boolean hasRtcFeature(final Device device) {
        checkNotNull(device, "Device cannot be null");
        return hasRtcFeature(device.getModel(), device.getFirmware());
    }

    public static boolean hasRtcFeature(final RemoteBluetoothDevice device) {
        checkNotNull(device, "Device cannot be null");
        return hasRtcFeature(device.getModel(), device.getFirmwareVersion());
    }

    public static boolean hasButtonFeature(final Model model) {
        return EnumSet.of(
                Model.CARD_BEACON_2,
                Model.TAG_BEACON,
                Model.BRACELET_TAG,
                Model.BRACELET_TAG_2,
                Model.UNIVERSAL_TAG,
                Model.MINEW_E5,
                Model.MINEW_E7,
                Model.MINEW_E8,
                Model.MINEW_I3,
                Model.MINEW_I7,
                Model.MINEW_S1,
                Model.PUCK_TAG
        ).contains(model);
    }

    public static boolean hasRtcFeature(final Model model, final String firmware) {
        checkNotNull(model, "Model cannot be null");
        checkNotNull(firmware, "Firmware version cannot be null");

        if (EnumSet.of(
                TAG_BEACON,
                SMART_BEACON_3,
                SMART_BEACON_3H,
                HEAVY_DUTY_BEACON,
                CARD_BEACON_2,
                TOUGH_BEACON_2,
                BRACELET_TAG,
                UNIVERSAL_TAG,
                BRACELET_TAG_2
        ).contains(model)) {
            return true;
        }

        final FirmwareVersion minFirmwareVersion = new FirmwareVersion("1.7");
        final FirmwareVersion deviceFirmwareVersion = new FirmwareVersion(firmware);

        return model == BEACON_PRO && deviceFirmwareVersion.isGreaterOrEqualTo(minFirmwareVersion);
    }

    public static boolean hasLightSensorFeature(final Device device) {
        checkNotNull(device, "Device cannot be null");
        return hasLightSensorFeature(device.getModel(), device.getFirmware());
    }

    public static boolean hasLightSensorFeature(final RemoteBluetoothDevice device) {
        checkNotNull(device, "Device cannot be null");
        return hasLightSensorFeature(device.getModel(), device.getFirmwareVersion());
    }

    public static boolean hasLightSensorFeature(final Model model, final String firmware) {
        checkNotNull(model, "Model cannot be null");
        checkNotNull(firmware, "Firmware version cannot be null");

        final FirmwareVersion minFirmwareVersion = new FirmwareVersion("1.7");
        final FirmwareVersion deviceFirmwareVersion = new FirmwareVersion(firmware);

        return model == BEACON_PRO && deviceFirmwareVersion.isGreaterOrEqualTo(minFirmwareVersion);
    }

    public static boolean hasRtcAndLightSensorFeatures(final Device device) {
        checkNotNull(device, "Device cannot be null");
        return hasRtcAndLightSensorFeatures(device.getModel(), device.getFirmware());
    }

    public static boolean hasRtcAndLightSensorFeatures(final RemoteBluetoothDevice device) {
        checkNotNull(device, "Device cannot be null");
        return hasRtcAndLightSensorFeatures(device.getModel(), device.getFirmwareVersion());
    }

    public static boolean hasRtcAndLightSensorFeatures(final Model model, final String firmware) {
        checkNotNull(model, "Model cannot be null");
        checkNotNull(firmware, "Firmware version cannot be null");

        return hasRtcFeature(model, firmware) && hasLightSensorFeature(model, firmware);
    }

    // Kontakt Telemetry broadcasting check methods

    public static boolean canTransmitKontaktTelemetry(final Device device) {
        checkNotNull(device, "Device cannot be null");
        return canTransmitKontaktTelemetry(device.getModel(), device.getFirmware());
    }

    public static boolean canTransmitKontaktTelemetry(final Model model, final String firmware) {
        checkNotNull(model, "Model cannot be null");
        checkNotNull(firmware, "Firmware version cannot be null");

        // Check if secure profile and not beacon pro
        if (model != BEACON_PRO && SECURE_PROFILES.contains(model)) {
            return true;
        }

        // If beacon pro then firmware revision must be checked additionally
        final FirmwareVersion minFirmwareVersion = new FirmwareVersion("1.10");
        final FirmwareVersion deviceFirmwareVersion = new FirmwareVersion(firmware);

        return model == BEACON_PRO && deviceFirmwareVersion.isGreaterOrEqualTo(minFirmwareVersion);
    }

    public static boolean canTransmitTTFrame(Model model){
        return EnumSet.of(
                TT_BEACON,
                MINEW_E5,
                MINEW_E7,
                MINEW_E8,
                MINEW_I3,
                MINEW_I7,
                MINEW_S1,
                PUCK_TAG
        ).contains(model);
    }

    // Interleaving packets check methods

    public static boolean isInterleavingAvailable(final Device device) {
        checkNotNull(device, "Device cannot be null");
        return isInterleavingAvailable(device.getModel(), device.getFirmware());
    }

    public static boolean isInterleavingAvailable(final Model model, final String firmware) {
        checkNotNull(model, "Model cannot be null");
        checkNotNull(firmware, "Firmware version cannot be null");

        if (EnumSet.of(
                BEACON_PRO,
                TAG_BEACON,
                SMART_BEACON_3,
                SMART_BEACON_3H,
                HEAVY_DUTY_BEACON,
                CARD_BEACON_2,
                TOUGH_BEACON_2,
                BRACELET_TAG,
                UNIVERSAL_TAG,
                BRACELET_TAG_2,
                MINEW_E5,
                MINEW_E7,
                MINEW_E8,
                MINEW_I3,
                MINEW_I7,
                MINEW_S1,
                PUCK_TAG,
                NANO_TAG,
                LANYARD_TAG
        ).contains(model)) {
            return true;
        }

        final FirmwareVersion minFirmwareVersion = new FirmwareVersion("4.1");
        final FirmwareVersion deviceFirmwareVersion = new FirmwareVersion(firmware);

        return deviceFirmwareVersion.isGreaterOrEqualTo(minFirmwareVersion);
    }

    public static boolean isGateway(Model model){
        return GATEWAY_MODELS.contains(model);
    }

}
